@@ -5,6 +5,7 @@ import sys
 from collections import defaultdict
 from copy import deepcopy
 from dataclasses import dataclass
+from datetime import date, datetime
 from enum import Enum
 from typing import (
     Any,
@@ -1979,6 +1980,48 @@ def test_post_init_not_called_without_override():
         BaseModel.model_post_init = original_base_model_post_init
 
 
+def test_model_post_init_subclass_private_attrs():
+    """https://github.com/pydantic/pydantic/issues/7293"""
+    calls = []
+
+    class A(BaseModel):
+        a: int = 1
+
+        def model_post_init(self, __context: Any) -> None:
+            calls.append(f'{self.__class__.__name__}.model_post_init')
+
+    class B(A):
+        pass
+
+    class C(B):
+        _private: bool = True
+
+    C()
+
+    assert calls == ['C.model_post_init']
+
+
+def test_model_post_init_correct_mro():
+    """https://github.com/pydantic/pydantic/issues/7293"""
+    calls = []
+
+    class A(BaseModel):
+        a: int = 1
+
+    class B(BaseModel):
+        b: int = 1
+
+        def model_post_init(self, __context: Any) -> None:
+            calls.append(f'{self.__class__.__name__}.model_post_init')
+
+    class C(A, B):
+        _private: bool = True
+
+    C()
+
+    assert calls == ['C.model_post_init']
+
+
 def test_deeper_recursive_model():
     class A(BaseModel):
         b: 'B'
@@ -2398,8 +2441,12 @@ def test_model_get_core_schema() -> None:
     class Model(BaseModel):
         @classmethod
         def __get_pydantic_core_schema__(cls, source_type: Any, handler: GetCoreSchemaHandler) -> CoreSchema:
-            assert handler(int) == {'type': 'int'}
-            assert handler.generate_schema(int) == {'type': 'int'}
+            schema = handler(int)
+            schema.pop('metadata', None)  # we don't care about this in tests
+            assert schema == {'type': 'int'}
+            schema = handler.generate_schema(int)
+            schema.pop('metadata', None)  # we don't care about this in tests
+            assert schema == {'type': 'int'}
             return handler(source_type)
 
     Model()
@@ -2497,6 +2544,53 @@ def test_validate_python_from_attributes() -> None:
     assert res == ModelFromAttributesFalse(x=1)
 
 
+@pytest.mark.parametrize(
+    'field_type,input_value,expected,raises_match,strict',
+    [
+        (bool, 'true', True, None, False),
+        (bool, 'true', True, None, True),
+        (bool, 'false', False, None, False),
+        (bool, 'e', ValidationError, 'type=bool_parsing', False),
+        (int, '1', 1, None, False),
+        (int, '1', 1, None, True),
+        (int, 'xxx', ValidationError, 'type=int_parsing', True),
+        (float, '1.1', 1.1, None, False),
+        (float, '1.10', 1.1, None, False),
+        (float, '1.1', 1.1, None, True),
+        (float, '1.10', 1.1, None, True),
+        (date, '2017-01-01', date(2017, 1, 1), None, False),
+        (date, '2017-01-01', date(2017, 1, 1), None, True),
+        (date, '2017-01-01T12:13:14.567', ValidationError, 'type=date_from_datetime_inexact', False),
+        (date, '2017-01-01T12:13:14.567', ValidationError, 'type=date_parsing', True),
+        (date, '2017-01-01T00:00:00', date(2017, 1, 1), None, False),
+        (date, '2017-01-01T00:00:00', ValidationError, 'type=date_parsing', True),
+        (datetime, '2017-01-01T12:13:14.567', datetime(2017, 1, 1, 12, 13, 14, 567_000), None, False),
+        (datetime, '2017-01-01T12:13:14.567', datetime(2017, 1, 1, 12, 13, 14, 567_000), None, True),
+    ],
+    ids=repr,
+)
+def test_model_validate_strings(field_type, input_value, expected, raises_match, strict):
+    class Model(BaseModel):
+        x: field_type
+
+    if raises_match is not None:
+        with pytest.raises(expected, match=raises_match):
+            Model.model_validate_strings({'x': input_value}, strict=strict)
+    else:
+        assert Model.model_validate_strings({'x': input_value}, strict=strict).x == expected
+
+
+@pytest.mark.parametrize('strict', [True, False])
+def test_model_validate_strings_dict(strict):
+    class Model(BaseModel):
+        x: Dict[int, date]
+
+    assert Model.model_validate_strings({'x': {'1': '2017-01-01', '2': '2017-01-02'}}, strict=strict).x == {
+        1: date(2017, 1, 1),
+        2: date(2017, 1, 2),
+    }
+
+
 def test_model_signature_annotated() -> None:
     class Model(BaseModel):
         x: Annotated[int, 123]
